<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AudioContainerControl</name>
    <message>
        <source>RAW (headerless) file format</source>
        <translation>Формат файла RAW (без заголовка)</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>Формат файла WAV</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>Linear PCM audio data</source>
        <translation>Аудио-данные Linear PCM</translation>
    </message>
</context>
<context>
    <name>BbCameraAudioEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Без сжатия</translation>
    </message>
    <message>
        <source>AAC compression</source>
        <translation>Сжатие AAC</translation>
    </message>
    <message>
        <source>PCM uncompressed</source>
        <translation>PCM без сжатия</translation>
    </message>
</context>
<context>
    <name>BbCameraMediaRecorderControl</name>
    <message>
        <source>Unable to retrieve mute status</source>
        <translation>Не удалось определить включён ли звук</translation>
    </message>
    <message>
        <source>Unable to retrieve audio input volume</source>
        <translation>Не удалось определить громкость входного звука</translation>
    </message>
    <message>
        <source>Unable to set mute status</source>
        <translation>Не удалось включить/выключить звук</translation>
    </message>
    <message>
        <source>Unable to set audio input volume</source>
        <translation>Не удалось установить громкость входного звука</translation>
    </message>
</context>
<context>
    <name>BbCameraSession</name>
    <message>
        <source>Camera provides image in unsupported format</source>
        <translation>Камера выдаёт изображение в неподдерживаемом формате</translation>
    </message>
    <message>
        <source>Could not load JPEG data from frame</source>
        <translation>Не удалось загрузить данные JPEG из кадра</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Unable to apply video settings</source>
        <translation>Не удалось применить настройки видео</translation>
    </message>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation>Не удалось открыть выходной файл:
%1</translation>
    </message>
    <message>
        <source>Unable to open camera</source>
        <translation>Не удалось открыть камеру</translation>
    </message>
    <message>
        <source>Unable to retrieve native camera orientation</source>
        <translation>Не удалось получить исходное положение камеры</translation>
    </message>
    <message>
        <source>Unable to close camera</source>
        <translation>Не удалось закрыть камеру</translation>
    </message>
    <message>
        <source>Unable to start video recording</source>
        <translation>Не удалось начать запись видео</translation>
    </message>
    <message>
        <source>Unable to stop video recording</source>
        <translation>Не удалось остановить запись видео</translation>
    </message>
</context>
<context>
    <name>BbCameraVideoEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Без сжатия</translation>
    </message>
    <message>
        <source>AVC1 compression</source>
        <translation>Сжатие AVC1</translation>
    </message>
    <message>
        <source>H264 compression</source>
        <translation>Сжатие H264</translation>
    </message>
</context>
<context>
    <name>BbImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Изображение JPEG</translation>
    </message>
</context>
<context>
    <name>BbVideoDeviceSelectorControl</name>
    <message>
        <source>Front Camera</source>
        <translation>Передняя камера</translation>
    </message>
    <message>
        <source>Rear Camera</source>
        <translation>Задняя камера</translation>
    </message>
    <message>
        <source>Desktop Camera</source>
        <translation>Виртуальная камера: рабочий стол</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>Изображение JPEG</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>QMediaRecorder::pause() не поддерживается camerabin2.</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>Служба не была запущена</translation>
    </message>
    <message>
        <source>Recording permissions are not available</source>
        <translation>Нет доступа на запись</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Ошибка камеры</translation>
    </message>
</context>
<context>
    <name>DSCameraSession</name>
    <message>
        <source>Camera not ready for capture</source>
        <translation>Камера не готова к захвату</translation>
    </message>
    <message>
        <source>Could not save image to file.</source>
        <translation>Не удалось сохранить изображение в файл.</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Неверный источник потока.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Попытка воспроизвести неверный ресурс Qt.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Система не может найти указанный файл.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Не удалось найти указанный сервер.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Носитель этого типа не поддерживается.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Не удалось загрузить источник.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Не удалось создать дескриптор презентации.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Не удалось получить количество потоков.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Не удалось создать топологию.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Невозможно воспроизводить потоки.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Не удалось воспроизвести.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Не удалось установить топологию.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Тип потока не известен.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Не удалось остановить.</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Не удалось приостановить.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Не удалось создать медиа-сессию.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Не удалось получить события сессии.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Не удалось переместиться.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Нефатальная ошибка медиа-сессии.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Серьёзная ошибка медиа-сессии.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Медиа не поддерживается - отсутствует кодек.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>не удалось запустить воспроизведение</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioEncoderSettingsControl</name>
    <message>
        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
        <translation>Звуковой кодек адаптивно-многочастотно-узкополосный (AMR-NB)</translation>
    </message>
    <message>
        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
        <translation>Звуковой кодек адаптивно-многочастотно-широкополосный (AMR-WB)</translation>
    </message>
    <message>
        <source>AAC Low Complexity (AAC-LC) audio codec</source>
        <translation>Звуковой кодек AAC низкой сложности (AAC-LC)</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Camera cannot be started without a viewfinder.</source>
        <translation>Невозможно запустить камеру без видоискателя.</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Drive mode not supported</source>
        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
        <translation>Режим множественной съёмки не поддерживается</translation>
    </message>
    <message>
        <source>Failed to capture image</source>
        <translation>Не удалось захватить изображение</translation>
    </message>
    <message>
        <source>Camera preview failed to start.</source>
        <translation>Не удалось запустить предпросмотр камеры.</translation>
    </message>
    <message>
        <source>Could not open destination file: %1</source>
        <translation>Не удалось открыть выходной файл: %1</translation>
    </message>
</context>
<context>
    <name>QAndroidImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Изображение JPEG</translation>
    </message>
</context>
<context>
    <name>QAndroidMediaContainerControl</name>
    <message>
        <source>MPEG4 media file format</source>
        <translation>Формат файла MPEG4</translation>
    </message>
    <message>
        <source>3GPP media file format</source>
        <translation>Фомат файла 3GPP</translation>
    </message>
    <message>
        <source>AMR NB file format</source>
        <translation>Формат файла AMR NB</translation>
    </message>
    <message>
        <source>AMR WB file format</source>
        <translation>Формат файла AMR WB</translation>
    </message>
</context>
<context>
    <name>QAndroidVideoEncoderSettingsControl</name>
    <message>
        <source>H.263 compression</source>
        <translation>Сжатие H.263</translation>
    </message>
    <message>
        <source>H.264 compression</source>
        <translation>Сжатие H.264</translation>
    </message>
    <message>
        <source>MPEG-4 SP compression</source>
        <translation>Сжатие MPEG-4 SP</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>Объект QAudioDecoder не имеет подходящей службы</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Отсутствует служба камеры</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Устройство не поддерживает захват изображений.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translation>Громкость должна быть от 0,0 до 1,0</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Невозможно проиграть поток типа: &lt;неизвестный&gt;</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Необработанное PCM-аудио</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>Системное устройство по умолчанию</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>Состояние не поддерживается.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Не удалось создать элемент источника звука</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Не удалось создать конвейер захвата медиа-данных.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>Не готово для захвата</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>Кодировщик изображений JPEG</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>Попытка воспроизвести неверный пользовательский поток</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Невозможно проиграть поток типа: &lt;неизвестный&gt;</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>Истекло время источника UDP</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation>Медиа-данные загружены в виде списка проигрывания</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Служба не была запущена</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Кодек и формат контейнера не совместимы.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Основная камера</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Передняя камера</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Попытка воспроизвести неверный ресурс Qt</translation>
    </message>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>Объект QMediaPlayer не имеет подходящей службы</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Не удалось добавить элементы для чтения только списка воспроизведения.</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Формат списка воспроизведения не поддерживается</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Не удалось получить доступ к файлу.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Формат списка воспроизведения не поддерживается.</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>CameraCapture предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>CameraRecorder предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>CameraExposure предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>CameraFocus предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>CameraFlash предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>CameraImageProcessing предоставляется камерой</translation>
    </message>
    <message>
        <source>CameraViewfinder is provided by Camera</source>
        <translation>CameraViewfinder предоставляется камерой</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>Неизвестный формат списка воспроизведения %1</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>неверная строка в файле списка воспроизведения</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>Предоставлен пустой файл</translation>
    </message>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 не существует</translation>
    </message>
</context>
<context>
    <name>QWinRTCameraImageCaptureControl</name>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Invalid photo data length.</source>
        <translation>Неверная длина данных фотографии.</translation>
    </message>
    <message>
        <source>Image saving failed</source>
        <translation>Не удалось сохранить изображение</translation>
    </message>
</context>
<context>
    <name>QWinRTImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Изображение JPEG</translation>
    </message>
</context>
</TS>
